<?php
$lang['error_insufficientparams'] = 'Verkeerde (of lege) parameters';
$lang['error_duplicatename'] = 'Er bestaat al een item met deze naam';
$lang['detail_page'] = 'Detail Pagina';
$lang['detail_template'] = 'Detail Sjabloon';
$lang['warning_preview'] = 'Waarschuwing: Dit voorbeeld panel gedraagt ​​zich als een browser-venster waarmee u kunt navigeren van de aanvankelijk bekeken pagina. Echter, als je dat doet, kan er onverwacht gedrag optreden. Navigeren vanaf de huidige pagina en terugkeren zal mogelijk niet het verwachte resultaat geven. <br/><strong>Opmerking:</ strong> De preview upload geen bestanden die u hebt geselecteerd voor uploaden.';
$lang['article'] = 'Artikel';
$lang['preview'] = 'Voorbeeld';
$lang['info_detail_returnid'] = 'Deze instelling wordt gebruikt om een pagina (en dus een sjabloon) te bepalen om te gebruiken om het detail artikel te tonen. Ge&iuml;ndividualiseerde Nieuws Detail URL&#039;s zullen niet werken als deze parameter niet is ingesteld op een geldige pagina.<br />
Bovendien, als deze voorkeur is ingesteld en de News tag is niet voorzien van de detailpage parameter, dan zal deze waarde worden gebruikt voor de detail links';
$lang['title_detail_returnid'] = 'Standaard pagina voor detail vertoningen';
$lang['title_submission_settings'] = 'Nieuws Aanmelding Instellingen';
$lang['title_fesubmit_settings'] = 'Frontend Aanmelding Instellingen';
$lang['title_notification_settings'] = 'Berichtgeving Instellingen';
$lang['title_detail_settings'] = 'Detail vertoning Instellingen';
$lang['error_invalidurl'] = 'Verkeerde Url <em>(kan zijn dat deze al in gebruik is, of dat er verkeerde tekens in staan)</em>';
$lang['url'] = 'Url';
$lang['expired_searchable'] = 'Verlopen artikelen kunnen verschijnen in de zoekresultaten';
$lang['helpshowall'] = 'Geef alle artikelen weer, ongeacht de einddatum';
$lang['error_invaliddates'] = 'Een of meerdere ingegeven datums zijn incorrect';
$lang['notify_n_draft_items_sub'] = '%d Nieuwsbericht(en)';
$lang['notify_n_draft_items'] = 'U heeft %s nieuwsbericht(en) die niet is/zijn gepubliceerd.';
$lang['unlimited'] = 'Onbeperkt';
$lang['none'] = 'Geen';
$lang['anonymous'] = 'Anoniem';
$lang['unknown'] = 'Onbekend';
$lang['fesubmit_redirect'] = 'PageID of alias om naartoe te gaan, nadat een bericht is geplaatst via de fesubmit-actie';
$lang['allow_summary_wysiwyg'] = 'Gebruik een WYSIWYG voor het samenvattings-veld';
$lang['title_browsecat_template'] = 'Browsen categoriesjabloon-editor';
$lang['title_browsecat_sysdefault'] = 'Standaard browse-categoriesjabloon';
$lang['browsecattemplate'] = 'Browsen categoriesjablonen';
$lang['error_filesize'] = 'Een ge&uuml;pload bestand overschrijdt de maximum toegestane grootte.';
$lang['post_date_desc'] = 'Bijdragedatum aflopend';
$lang['post_date_asc'] = 'Bijdragedatum oplopend';
$lang['expiry_date_desc'] = 'Verloopdatum aflopend';
$lang['expiry_date_asc'] = 'Verloopdatum oplopend';
$lang['title_desc'] = 'Titel aflopend';
$lang['title_asc'] = 'Titel oplopend';
$lang['status_desc'] = 'Status Oplopend';
$lang['status_asc'] = 'Status Aflopend';
$lang['fesubmit_status'] = 'De status van nieuwsberichten ingediend via de frontend';
$lang['error_invalidfiletype'] = 'Kan dit type bestand niet uploaden';
$lang['error_upload'] = 'Probleem opgetreden tijdens uploaden bestand';
$lang['error_movefile'] = 'Kan bestand %s niet aanmaken';
$lang['error_mkdir'] = 'Kan map %s niet aanmaken';
$lang['expiry_interval'] = 'Het aantal dagen (volgens standaard) voordat een bericht verloopt (als expiry geselecteerd is)';
$lang['removed'] = 'Verwijderd';
$lang['msg_contenttype_removed'] = 'Het nieuwsinhoudtype is verwijderd. Plaats de {news} tags met de geschikte parameters in uw sjabloon of in uw pagina om deze functionaliteit te vervangen.';
$lang['delete_selected'] = 'Verwijder geselecteerde berichten';
$lang['areyousure_deletemultiple'] = 'Weet u zeker dat al deze nieuwsberichten verwijderd moeten worden?\nDeze actie kan niet ongedaan gemaakt worden!';
$lang['error_templatenamexists'] = 'Een sjabloon met deze naam bestaat al';
$lang['error_noarticlesselected'] = 'Er zijn geen berichten geselecteerd';
$lang['reassign_category'] = 'Verander categorie in';
$lang['select'] = 'Selecteer';
$lang['approve'] = 'Zet status op &#039;Gepubliceerd&#039;';
$lang['revert'] = 'Zet status op &#039;Concept&#039;';
$lang['hide_summary_field'] = 'Verberg het samenvattingsveld tijdens toevoegen of bewerken van berichten';
$lang['textbox'] = 'Tekstinvoer';
$lang['checkbox'] = 'Vinkvakje';
$lang['textarea'] = 'Tekstvak';
$lang['file'] = 'Bestand';
$lang['auto_create_thumbnails'] = 'Maak automatisch miniaturen aan van bestanden met deze extensies';
$lang['allowed_upload_types'] = 'Sta alleen uploaden van bestanden met deze extensie toe';
$lang['fielddefupdated'] = 'Velddefinitie bijgewerkt';
$lang['editfielddef'] = 'Bewerk velddefinitie';
$lang['up'] = 'Op';
$lang['down'] = 'Neer';
$lang['fielddefdeleted'] = 'Velddefinitie verwijderd';
$lang['nameexists'] = 'Een veld met die naam bestaat al';
$lang['notanumber'] = 'Maximum lengte is geen getal';
$lang['fielddef'] = 'Velddefinitie';
$lang['fielddefadded'] = 'Velddefinitie toegevoegd';
$lang['public'] = 'Publiek (openbaar)';
$lang['type'] = 'Type ';
$lang['info_maxlength'] = 'De maximum lengte betreft alleen tekstinvoervelden';
$lang['maxlength'] = 'Maximum lengte';
$lang['addfielddef'] = 'Voeg velddefinitie toe';
$lang['customfields'] = 'Velddefinities';
$lang['deprecated'] = 'vervallen';
$lang['subject_newnews'] = 'Er is een nieuw artikel geplaatst';
$lang['email_subject'] = 'Het onderwerp van de uitgaande E-mail';
$lang['email_template'] = 'Het formaat van het E-mailbericht';
$lang['formsubmit_emailaddress'] = 'E-mailadres om de bevestiging van ingezonden nieuws op te ontvangen';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Uploads-categorie';
$lang['title_available_templates'] = 'Beschikbare Sjablonen';
$lang['resettodefault'] = 'Herstel naar standaard waarden';
$lang['title_form_template'] = 'Formuliersjabloon-editor';
$lang['title_detail_template'] = 'Artikelsjabloon-editor';
$lang['title_summary_template'] = 'Samenvattingssjabloon-editor';
$lang['prompt_templatename'] = 'Sjabloonnaam';
$lang['prompt_template'] = 'Sjabloonbron';
$lang['title_form_sysdefault'] = 'Standaard formuliersjabloon';
$lang['title_summary_sysdefault'] = 'Standaard samenvattingssjabloon';
$lang['title_detail_sysdefault'] = 'Standaard artikelsjabloon';
$lang['info_sysdefault2'] = '<strong>Opmerking:</strong> Dit tabblad bevat tekstgebieden om een groep sjablonen te bewerken die getoond worden als u een nieuwssamenvatting, -overzicht of formulier-sjabloon aanmaakt. Veranderen van inhoud in dit tabblad en versturen daarvan heeft <strong>geen effect</strong> op de bestaande weergaven.';
$lang['info_sysdefault'] = '(de inhoud die standaard wordt gebruikt bij het aanmaken van een nieuw sjabloon)';
$lang['template'] = 'Sjabloon';
$lang['prompt_name'] = 'Naam';
$lang['prompt_default'] = 'Standaard';
$lang['prompt_newtemplate'] = 'Maak een nieuw sjabloon aan';
$lang['help_pagelimit'] = 'Maximum aantal te tonen items (per pagina).  Als deze parameter niet is opgegeven, zullen alle resulterende items worden getoond. Als er een maximum is opgegeven, zal er bij meer resultaten dan opgegeven een tekst en link verschijnen om door de resultaten te kunnen scrollen.';
$lang['prompt_page'] = 'Pagina';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'van';
$lang['prompt_pagelimit'] = 'Paginalimiet';
$lang['prompt_sorting'] = 'Sorteren op';
$lang['title_filter'] = 'Filters ';
$lang['published'] = 'Gepubliceerd';
$lang['draft'] = 'Concept';
$lang['expired'] = 'Verlopen';
$lang['author'] = 'Auteur';
$lang['sysdefaults'] = 'Terug naar standaardwaarde';
$lang['restoretodefaultsmsg'] = 'Deze actie herstelt de inhoud van het sjabloon naar de standaardwaarde. Weet u zeker dat u door wilt gaan?';
$lang['addarticle'] = 'Artikel toevoegen';
$lang['articleadded'] = 'Het artikel is toegevoegd.';
$lang['articleupdated'] = 'Het artikel is met succes bijgewerkt.';
$lang['articledeleted'] = 'Het artikel is verwijderd.';
$lang['addcategory'] = 'Categorie toevoegen';
$lang['categoryadded'] = 'De categorie is toegevoegd.';
$lang['categoryupdated'] = 'De categorie is bijgewerkt.';
$lang['categorydeleted'] = 'De categorie is verwijderd.';
$lang['addnewsitem'] = 'Nieuwsbericht toevoegen';
$lang['allcategories'] = 'Alle categorie&euml;n';
$lang['allentries'] = 'Alle toevoegingen';
$lang['areyousure'] = 'Weet u zeker dat u wilt verwijderen?';
$lang['articles'] = 'Artikelen';
$lang['cancel'] = 'Annuleren';
$lang['category'] = 'Categorie';
$lang['categories'] = 'Categorie&euml;n';
$lang['default_category'] = 'Standaardcategorie';
$lang['content'] = 'Inhoud';
$lang['dateformat'] = '%s niet in een geldig yyyy-mm-dd hh:mm:ss formaat';
$lang['delete'] = 'Verwijder';
$lang['description'] = 'Toevoegen, bewerken en verwijderen van nieuwsberichten';
$lang['formtemplate'] = 'Formuliersjablonen';
$lang['detailtemplate'] = 'Artikelsjablonen';
$lang['default_templates'] = 'Standaardsjablonen';
$lang['detailtemplateupdated'] = 'Het bewerkte artikelsjabloon is opgeslagen in de database.';
$lang['displaytemplate'] = 'Toon sjabloon';
$lang['edit'] = 'Bewerk';
$lang['enddate'] = 'Einddatum';
$lang['endrequiresstart'] = 'Het invoeren van een einddatum vereist ook een begindatum';
$lang['entries'] = '%s Items';
$lang['status'] = 'Status ';
$lang['expiry'] = 'Vervaldatum';
$lang['filter'] = 'Filter ';
$lang['more'] = 'Meer';
$lang['category_label'] = 'Categorie:';
$lang['author_label'] = 'Ingezonden door:';
$lang['extra_label'] = 'Extra :';
$lang['moretext'] = 'Meer tekst';
$lang['name'] = 'Naam';
$lang['news'] = 'Nieuws ';
$lang['news_return'] = 'Terug';
$lang['newcategory'] = 'Nieuwe categorie';
$lang['needpermission'] = 'U heeft &#039;%s&#039; rechten nodig om deze functie te gebruiken.';
$lang['nocategorygiven'] = 'Geen categorie ingevuld';
$lang['startdatetoolate'] = 'De begindatum is te laat (later dan de einddatum?)';
$lang['nocontentgiven'] = 'Geen inhoud ingevuld';
$lang['noitemsfound'] = '<strong>Geen</strong> items gevonden voor de categorie: %s';
$lang['nopostdategiven'] = 'Geen plaatsingsdatum ingevuld';
$lang['note'] = '<em>Opgelet:</em> Data in het volgende formaat opgeven &#039;yyyy-mm-dd hh:mm:ss&#039; .';
$lang['notitlegiven'] = 'Geen titel ingevuld';
$lang['nonamegiven'] = 'Geen naam ingevuld';
$lang['numbertodisplay'] = 'Aantal weer te geven (leeg is alles weergeven)';
$lang['print'] = 'Afdrukken';
$lang['postdate'] = 'Plaatsingsdatum';
$lang['postinstall'] = 'Zorg ervoor dat gebruikers die nieuwsberichten beheren &quot;Modify News&quot; rechten krijgen.';
$lang['selectcategory'] = 'Selecteer een categorie';
$lang['showchildcategories'] = 'Toon onderliggende categorie&euml;n';
$lang['sortascending'] = 'Sorteer oplopend';
$lang['startdate'] = 'Begindatum';
$lang['startoffset'] = 'Begin tonen bij het n-de item';
$lang['startrequiresend'] = 'Het toevoegen van een begindatum vereist ook een einddatum';
$lang['submit'] = 'Versturen';
$lang['summary'] = 'Samenvatting';
$lang['summarytemplate'] = 'Samenvattingssjabloon';
$lang['summarytemplateupdated'] = 'Het nieuwssamenvattingssjabloon is bijgewerkt.';
$lang['title'] = 'Titel';
$lang['options'] = 'Opties';
$lang['optionsupdated'] = 'De opties zijn bijgewerkt.';
$lang['useexpiration'] = 'Gebruik vervaldatum';
$lang['eventdesc-NewsArticleAdded'] = 'Een tag die wordt aangeroepen als een bericht is toegevoegd.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Verzonden als een bericht is toegevoegd.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id van het bericht</li>
<li>\&quot;category_id\&quot; - Id van de categorie van dit bericht</li>
<li>\&quot;title\&quot; - Titel van het bericht</li>
<li>\&quot;content\&quot; - Inhoud van het bericht</li>
<li>\&quot;summary\&quot; - Samenvatting van het bericht</li>
<li>\&quot;status\&quot; - Status van het bericht (&quot;draft&quot; of &quot;publish&quot; d.w.z. concept of publiceren)</li>
<li>\&quot;start_time\&quot; - Datum vanaf dat het bericht zichtbaar moet zijn</li>
<li>\&quot;end_time\&quot; - Datum totdat het bericht zichtbaar moet zijn</li>
<li>\&quot;useexp\&quot; - Of de verloopdatum genegeerd moet worden of niet</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Een tag die wordt aangeroepen als een bericht is bewerkt.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Verzonden als een bericht is bewerkt.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id van het bericht</li>
<li>\&quot;category_id\&quot; - Id van de categorie van dit bericht</li>
<li>\&quot;title\&quot; - Titel van het bericht</li>
<li>\&quot;content\&quot; - Inhoud van het bericht</li>
<li>\&quot;summary\&quot; - Samenvatting van het bericht</li>
<li>\&quot;status\&quot; - Status van het bericht (&quot;draft&quot; of &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Datum vanaf dat het bericht zichtbaar moet zijn</li>
<li>\&quot;end_time\&quot; - Datum totdat het bericht zichtbaar moet zijn</li>
<li>\&quot;useexp\&quot; - Of de verloopdatum genegeerd moet worden of niet</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Een tag die wordt aangeroepen als een bericht is verwijderd.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Verzonden als een bericht is verwijderd.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id van het bericht</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Een tag die wordt aangeroepen als een categorie is toegevoegd.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Verzonden als een categorie is toegevoegd.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id van de nieuwscategorie</li>
<li>\&quot;name\&quot; - Naam van de nieuwscategorie</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Een tag die wordt aangeroepen als een categorie is bewerkt.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Verzonden als een categorie is bewerkt.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id van de nieuwscategorie</li>
<li>\&quot;name\&quot; - Naam van de nieuwscategorie</li>
<li>\&quot;origname\&quot; - De originele naam van de nieuwscategorie</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Een tag die wordt aangeroepen als een categorie is verwijderd.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Verzonden als een categorie is verwijderd.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id van het bericht</li>
<li>\&quot;name\&quot; - Naam van de verwijderde categorie</li>
</ul>
';
$lang['help_articleid'] = 'Deze parameter is alleen van toepassing op het detail overzicht. Het specificeert welk nieuws artikel wordt getoond in het detail overzicht. Als de speciale waarde &#039;-1&#039; wordt  gebruikt dan zal de module het nieuwste, gepubliceerde en niet verlopen artikel tonen';
$lang['helpnumber'] = 'Maximum aantal te tonen items -- door dit leeg te laten worden alle items getoond. Het is een synoniem voor de pagina limiet parameter.';
$lang['helpstart'] = 'Begin bij het zoveelste... item -- geen waarde ingevoerd start dan bij het eerste item.';
$lang['helpcategory'] = 'Toon alleen items van die categorie. <b>Gebruik * achter de naam om onderliggende items te tonen</b>. Meerdere categorie&euml;n scheiden met een komma. Geen waarde laat alle categorie&euml;n zien. Deze parameter kan ook gebruikt worden bij een frontend actie, maar dan kan alleen &eacute;&eacute;n categorie naam worden gebruikt.';
$lang['helpmoretext'] = 'Tekst die wordt getoond aan het eind van een nieuwsbericht als de samenvatting te lang is. Standaard &quot;Meer&quot;';
$lang['helpsummarytemplate'] = 'Gebruik een ander sjabloon voor het tonen van het samengevatte bericht. Dit sjabloon moet bestaan en zichtbaar zijn in het samenvattingssjabloon-tabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
$lang['helpformtemplate'] = 'Gebruik een database-sjabloon om het artikelinzendingsformulier te tonen. Dit sjabloon moet bestaan en zichtbaar zijn in het formuliersjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
$lang['helpbrowsecattemplate'] = 'Gebruik een database-sjabloon om de categorie-browser te tonen. Dit sjabloon moet bestaan en zichtbaar zijn in het formuliersjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
$lang['helpdetailtemplate'] = 'Gebruik een ander database-sjabloon voor het tonen van het volledige bericht. Dit sjabloon moet bestaan en zichtbaar zijn in het artikelsjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is. ';
$lang['helpsortby'] = 'Veld om op te sorteren. Mogelijkheden zijn: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  Standaard is het &quot;news_date&quot;. Als &quot;random&quot; is opgegeven, wordt de sortasc-parameter genegeerd.';
$lang['helpsortasc'] = 'Sorteer nieuwsberichten in oplopende volgorde in plaats van aflopend.';
$lang['helpdetailpage'] = 'Pagina om het nieuwsbericht in te tonen. Dit kan een paginaalias of -id zijn. Gebruikt om het volledige artikel in een ander sjabloon te tonen dan de samenvatting.';
$lang['helpshowarchive'] = 'Toon alleen verlopen artikelen.';
$lang['helpbrowsecat'] = 'Toon een doorbladerbare categorielijst.';
$lang['helpaction'] = 'Negeer de standaardtaak. Mogelijke waarden zijn:
<ul>
<li>&quot;detail&quot; - toon van een specifiek artikel ID de detail weergave.</li>
<li>&quot;default&quot; - toon de samenvattingsweergave</li>
<li>&quot;fesubmit&quot; - toon het frontend formulier om (ingelogde) gebruikers de mogelijkheid te geven om nieuwsberichten aan te leveren. Voeg de <code>{cms_init_editor}</code> tag toe aan de metadata sectie om de geselecteerde WYSIWYG editor toe te passen. (Websitebeheer >> Algemene Instellingen)</li>
<li>&quot;browsecat&quot; - toon een overzichtslijst van categori&euml;n.</li>
</ul>';
$lang['help'] = '<h3>Belangrijke opmerkingen</h3>

<p>In de versie 2.9 en hoger van de nieuws-module is de formatpostdate functie uit het sjabloon verwijderd, daarnaast wordt ook dateformat parameter niet meer gebruikt.  U zal gebruik moeten maken van de cms_date_format functie (zoals nu wordt gebruikt in de standaard sjablonen) om de datumnotificaties te wijzigen, en plaats de entry->postdate in plaats van de entry->formatpostdate in uw sjabloon.</p>

<p>Deze versie van News is nieuwer dan degene die met versie 1.1 van CMSMS werd meegeleverd. Als u deze versie van News gebruikt moet u zeer voorzichtig zijn met het upgraden van CMSMS om te voorkomen dat gegevens in de modules/News map worden overschreven.</p>



	<h3>Wat doet het?</h3>
	<p>News is een module om nieuws te tonen op uw pagina, vergelijkbaar met een blog, maar met meer mogelijkheden! Als de module ge&iuml;nstalleerd is, wordt een News-beheerscherm aan het beheerpaneel toegevoegd waarmee u nieuwscategorie&euml;n kunt selecteren en aanmaken. Als een nieuwscategorie aangemaakt of geselecteerd is, worden een lijst met nieuwsberichten voor die categorie getoond. Vanuit deze lijst kunnen berichten worden gecreeerd, bewerkt of verwijderd.</p>
	<h3>Sjabloonvariabelen</h3>
	<ul>
		<li><b>itemcount</b> - Het aantal nieuwsberichten om te tonen.</li>
		<li><b>entry->authorname</b> - De volledige naam van de auteur, inclusief de voor- en achternaam.</li>
	</ul>
	<h3>Beveiliging</h3>
	<p>De gebruiker moet lid zijn van een groep met groepsrecht &#039;Modify News&#039; om berichten te mogen aanmaken, bewerken of verwijderen.</p>
	<p>Om een opmaaksjabloon te mogen bewerken moet de gebruiker lid zijn van een groep met &#039;Modify Templates&#039; rechten.</p>
	<p>Algemene News-voorkeuren kunnen alleen door gebruikers veranderd worden die onderdeel zijn van een groep met &#039;Modify Site Preferences&#039; rechten.</p>
	<h3>Hoe gebruik ik het?</h3>
	<p>De eenvoudigste manier om deze module te gebruiken is de {news} tag in uw sjabloon of pagina op te nemen op die plek waar de nieuwsberichten getoond moeten worden. De code zal er dan ongeveer als volgt uitzien: <code>{news number=&#039;5&#039;}</code></p>
<h3>Sjablonen</h3>
	<p>Vanaf versie 2.3 ondersteunt News meerdere database-sjablonen en is de ondersteuning van extra bestandssjablonen gestaakt. Gebruikers die de oude bestandssjablonen gebruikten, moeten voor ieder sjabloon de volgende stappen doorlopen:
<ul>
<li>Kopieer de bestandssjabloon naar het clipboard</li>
<li>Maak een nieuw database-sjabloon aan <em>(een samenvattings- of berichtensjabloon)</em>. Geef het nieuwe sjabloon dezelfde naam (inclusief de .tpl extensie) als de oude bestandssjabloon en plak de inhoud van het clipboard erin.</li>
<li>Klik Versturen</li>
</ul>
Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
$lang['qca'] = 'P0-1157065314-1313856308297';
$lang['utma'] = '156861353.1414653339.1316370951.1316370951.1316370951.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1316370951.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
?>